@@ -18,11 +18,14 @@ exports.push([module.id, %%s, ""]);
 // exports
 """ % os.getenv("NODE_PATH")
 
+
 def replace(match):
-	if match.group(1).startswith("data:"):
-		return match.group(0)
-	path = match.group(1) if match.group(1).startswith(".") else os.path.join(".", match.group(1))
-	return """url(" + require("%s") + "%s)""" % (path, match.group(2))
+    if match.group(1).startswith("data:"):
+        return match.group(0)
+    path = match.group(1) if match.group(1).startswith(
+        ".") else os.path.join(".", match.group(1))
+    return """url(" + require("%s") + "%s)""" % (path, match.group(2))
+
 
 f = sys.stdin.read()
 print(template % re.sub(CSS_URL, replace, json.dumps(f)))
